from django.template.loader import render_to_string, TemplateDoesNotExist


def get_article_links_by_category():
    category_data = {'know-yourself': _get_category_by_id('know-yourself'),
                     'make-your-way': _get_category_by_id('make-your-way'),
                     'weave-together': _get_category_by_id('weave-together'),
                     'know-world': _get_category_by_id('know-world')
                     }
    return category_data


def _get_category_by_id(id):
    path = 'hx_toolkit_output/summary/' + id + ".html"
    try:
        return render_to_string(path)
    except TemplateDoesNotExist:
        return None


def get_rendered_article_by_id(article_id):
    article_file = "hx_toolkit_output/by_id/" + article_id + ".html"
    return render_to_string(article_file)


def get_article_by_phase_quarter_week(phase, quarter, week):
    week = str(week)
    root = "hx_toolkit_output/weekly/"

    path = root + phase + "/" + quarter + "/" + week + ".html"

    try:
        return render_to_string(path)
    except TemplateDoesNotExist:
        return None



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-12-26 17:46
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hx_toolkit', '0005_article_image_alt_text'),
    ]

    operations = [
        migrations.AlterField(
            model_name='article',
            name='related_articles',
            field=models.ManyToManyField(blank=True, related_name='related_article', to='hx_toolkit.Article'),
        ),
    ]



from django.template.loader import render_to_string


def render_article_html(article, is_short=False):
    template = 'message_long.html'
    if is_short:
        template = 'message_short.html'
    article_string = render_to_string(template, {'article': article})
    return article_string


def render_category_links(links):
    template = 'summary_links.html'
    links_string = render_to_string(template, {'links': links})
    return links_string



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-12-12 00:31
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Article',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255)),
                ('short_body', models.TextField(blank=True, null=True)),
                ('long_body', models.TextField()),
                ('image', models.ImageField(upload_to=b'thrive_images')),
                ('slug', models.SlugField(unique=True)),
                ('phase', models.CharField(blank=True, choices=[(b'A', b'Phase A'), (b'B', b'Phase B'), (b'C', b'Phase C')], max_length=1, null=True)),
                ('quarter', models.CharField(blank=True, choices=[(b'Au', b'Autumn'), (b'Wi', b'Winter'), (b'Sp', b'Spring'), (b'Su', b'Summer')], max_length=2, null=True)),
                ('week', models.IntegerField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255)),
                ('slug', models.SlugField(unique=True)),
            ],
            options={
                'verbose_name_plural': 'Categories',
            },
        ),
        migrations.CreateModel(
            name='RelatedArticle',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('parent_article', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='parent_article', to='hx_toolkit.Article')),
                ('related_article', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='related_article', to='hx_toolkit.Article')),
            ],
        ),
        migrations.CreateModel(
            name='ResourceLink',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.URLField()),
                ('title', models.CharField(max_length=255)),
            ],
        ),
        migrations.AddField(
            model_name='article',
            name='category',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='hx_toolkit.Category'),
        ),
        migrations.AddField(
            model_name='article',
            name='related_articles',
            field=models.ManyToManyField(blank=True, related_name='_article_related_articles_+', to='hx_toolkit.Article'),
        ),
        migrations.AddField(
            model_name='article',
            name='related_links',
            field=models.ManyToManyField(blank=True, to='hx_toolkit.ResourceLink'),
        ),
    ]
